@@ -4,7 +4,7 @@ use 5.006001;
 use warnings;
 use Carp;
 require Exporter;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our @EXPORT = ();
 our @EXPORT_BASE = qw(field const stub super);
 our @EXPORT_OK = (@EXPORT_BASE, qw(id WWW XXX YYY ZZZ));
@@ -278,9 +278,12 @@ sub id {
 # It's super, man.
 #===============================================================================
 package DB;
-sub super_args { 
-    my @dummy = caller(@_ ? $_[0] : 2); 
-    return @DB::args;
+{
+    no warnings 'redefine';
+    sub super_args { 
+        my @dummy = caller(@_ ? $_[0] : 2); 
+        return @DB::args;
+    }
 }
 
 package Class::Spiffy;
